[Scummvm-cvs-logs] SF.net SVN: scummvm: [32316] scummvm/trunk/backends/platform/sdl/sdl.cpp

fingolfin at users.sourceforge.net fingolfin at users.sourceforge.net
Tue May 27 10:01:06 CEST 2008


Revision: 32316
          http://scummvm.svn.sourceforge.net/scummvm/?rev=32316&view=rev
Author:   fingolfin
Date:     2008-05-27 01:01:06 -0700 (Tue, 27 May 2008)

Log Message:
-----------
Reduce audio buffer size, as indicated on scummvm-devel

Modified Paths:
--------------
    scummvm/trunk/backends/platform/sdl/sdl.cpp

Modified: scummvm/trunk/backends/platform/sdl/sdl.cpp
===================================================================
--- scummvm/trunk/backends/platform/sdl/sdl.cpp	2008-05-27 07:45:13 UTC (rev 32315)
+++ scummvm/trunk/backends/platform/sdl/sdl.cpp	2008-05-27 08:01:06 UTC (rev 32316)
@@ -403,10 +403,10 @@
 		_samplesPerSec = SAMPLES_PER_SEC;
 
 	// Determine the sample buffer size. We want it to store enough data for
 	// about 1/10th of a second. Note that it must be a power of two.
 	// So e.g. at 22050 Hz, we request a sample buffer size of 2048.
-	int samples = 0x8000;
-	while (10 * samples >= _samplesPerSec) {
+	int samples = 8192;
+	while (64 * samples >= _samplesPerSec) {
 		samples >>= 1;
 	}
 
@@ -403,10 +403,10 @@
 
 	// Determine the sample buffer size. We want it to store enough data for
-	// about 1/10th of a second. Note that it must be a power of two.
+	// about 1/64th of a second. Note that it must be a power of two.
 	// So e.g. at 22050 Hz, we request a sample buffer size of 2048.


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list